==> pnetC-0.6.0.tar.gz: pnetC-0.6.0/libc/malloc/calloc.c <==
/*
 * calloc.c - Allocate cleared memory from the C heap.
 *
 * This file is part of the Portable.NET C library.
 * Copyright (C) 2002  Southern Storm Software, Pty Ltd.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include <malloc.h>
#include <stdint.h>
#include <errno.h>

typedef __csharp__(System.Runtime.InteropServices.Marshal) Marshal;

void *
__calloc(size_t nmemb, size_t size)
{
  void *ptr;
  unsigned long long full_size;

  /* Validate the parameters */
  full_size = ((unsigned long long)nmemb) * ((unsigned long long)size);
  if(size == 0)
    {
      size = 1;
    }
  else if(size > (unsigned long long)(long long)INT32_MAX)
    {
      errno = ENOMEM;
      return 0;
    }

  /* Allocate memory from the runtime engine */
  ptr = (void *)Marshal::AllocHGlobal((__native__ int)full_size);
  if(ptr != 0)
    {
      return ptr;
    }
  errno = ENOMEM;
  return ptr;
}

weak_alias(__calloc, calloc)

==> pnetC-0.7.4.tar.gz: pnetC-0.7.4/libc/malloc/calloc.c <==
/*
 * calloc.c - Allocate cleared memory from the C heap.
 *
 * This file is part of the Portable.NET C library.
 * Copyright (C) 2002  Southern Storm Software, Pty Ltd.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include <malloc.h>
#include <stdint.h>
#include <errno.h>

__using__ System::Runtime::InteropServices::Marshal;

void *
__calloc(size_t nmemb, size_t size)
{
  void *ptr;
  unsigned long long full_size;

  /* Validate the parameters */
  full_size = ((unsigned long long)nmemb) * ((unsigned long long)size);
  if(size == 0)
    {
      size = 1;
    }
  else if(size > (unsigned long long)(long long)INT32_MAX)
    {
      errno = ENOMEM;
      return 0;
    }

  /* Allocate memory from the runtime engine */
  ptr = (void *)Marshal::AllocHGlobal((long)full_size);
  if(ptr != 0)
    {
      return ptr;
    }
  errno = ENOMEM;
  return ptr;
}

weak_alias(__calloc, calloc)
